(TeX-add-style-hook "clValid"
 (lambda ()
    (LaTeX-add-bibliographies
     "ClusterRefs")
    (LaTeX-add-labels
     "sec:introduction"
     "sec:measures"
     "subsec:internal"
     "subsec:stability"
     "subsec:biological"
     "sec:clustering"
     "sec:illustration"
     "subsec:ExInternal"
     "fig:internPlot"
     "subsec:ExStability"
     "fig:stabPlot"
     "subsec:ExBiological"
     "fig:BHI"
     "fig:BSI"
     "fig:BHI2"
     "fig:BSI2"
     "subsec:ExRankAggreg"
     "subsec:ExFurtherAnalysis"
     "fig:hplot"
     "sec:discussion")
    (TeX-run-style-hooks
     "Sweave"
     "gbMacros"
     "natbib"
     "round"
     "euscript"
     "mathcal"
     "relsize"
     "hyperref"
     "color"
     "graphics"
     "amsfonts"
     "amssymb"
     "amsmath"
     "latex2e"
     "art11"
     "article"
     "11pt")))

